CollectionApi

Struct CollectionApi 

pub struct CollectionApi<'a> { /* private fields */ }
Sub-API for collection endpoints.

Implementations

Source

impl<'a> CollectionApi<'a>

pub async fn get_user_collections(&self) -> Result<Value, RsError>

Returns a list of the user’s collections.

Arguments

None

Examples
let status = client.collection().get_user_collections().await?;
pub async fn add_resource_to_collection( &self, request: AddResourceToCollectionRequest, ) -> Result<Value, RsError>

Add a resource to a collection.

Arguments
Returns

True or false depending on operation success.

TODO: Errors
TODO: Examples
pub async fn remove_resource_from_collection( &self, request: RemoveResourceFromCollectionRequest, ) -> Result<Value, RsError>

Remove a resource from a collection.

Arguments
Returns

True or false depending on operation success.

TODO: Errors
TODO: Examples
pub async fn create_collection( &self, request: CreateCollectionRequest, ) -> Result<Value, RsError>

Create a new collection for the user.

Arguments
Returns

Integer|bool - ID of the collection created, false if collection creation is not permitted

TODO: Errors
TODO: Examples
pub async fn delete_collection( &self, request: DeleteCollectionRequest, ) -> Result<Value, RsError>

Deletes a collection. The user must have write access to this collection.

Arguments
Returns

True or false depending on operation success.

TODO: Errors
TODO: Examples
pub async fn search_public_collections( &self, request: SearchPublicCollectionsRequest, ) -> Result<Value, RsError>

Search public and featured collections.

Arguments
Returns

A list of matching public or featured collections.

TODO: Errors
TODO: Examples
pub async fn get_collection( &self, request: GetCollectionRequest, ) -> Result<Value, RsError>

Get collection details.

This requires administrator access (“a” permission).

Arguments
Returns

The collection details including owner name, description, public/private status, thumbnail image reference. All available columns are returned.

TODO: Errors
TODO: Examples
pub async fn save_collection( &self, request: SaveCollectionRequest, ) -> Result<Value, RsError>

Save collection data.

Arguments
Returns

Returns false if access control fails or invalid arguments have been received (e.g ref not a number), true otherwise.

TODO: Errors
TODO: Examples
pub async fn show_hide_collection( &self, request: ShowHideCollectionRequest, ) -> Result<Value, RsError>

Shows or hides a collection from the user’s drop-down list.

Arguments
Returns

True or false depending on operation success.

TODO: Errors
TODO: Examples
pub async fn send_collection_to_admin( &self, request: SendCollectionToAdminRequest, ) -> Result<Value, RsError>

Sends a copy of the collection for admin review.

Arguments
Returns

True or false depending on operation success.

TODO: Errors
TODO: Examples

Get ResourceSpace featured collections (category).

Arguments
Returns

If successful, a 200 HTTP status will be returned with the body containing an array. If the parent is invalid an empty array will be returned instead.

TODO: Errors
TODO: Examples
pub async fn delete_resources_in_collection( &self, request: DeleteResourcesInCollectionRequest, ) -> Result<Value, RsError>

Deletes all resources in a collection.

The user must have edit access to the resources, permission to delete resources and the collection must be writable.

Arguments
Returns

True or false depending on operation success.

TODO: Errors
TODO: Examples
pub async fn get_collections_resource_count( &self, request: GetCollectionsResourceCountRequest, ) -> Result<Value, RsError>

Get the total resource count for a list of collections.

Requires permission b and the collections must be readable by the user.

Arguments
Returns

Array of collections and their total resource count. Note the returned array may not contain keys for all input IDs if validation fails for some.

TODO: Errors
TODO: Examples