pub struct SaveCollectionColdata {
pub keywords: Option<List<String>>,
pub allow_changes: Option<u8>,
pub users: Option<List<String>>,
pub name: Option<String>,
pub public: Option<u8>,
pub type: Option<u8>,
pub parent: Option<u32>,
pub force_featured_collection_type: Option<u8>,
pub thumbnail_selection_method: Option<u32>,
pub bg_img_resource_ref: Option<u32>,
}Fields
keywords: Option<List<String>>Comma-separated value of keywords to be associated with this collection.
allow_changes: Option<u8>To set whether other users are allowed to add/remove resources when collection is shared or is public. The allowed value is 0 or 1.
users: Option<List<String>>Comma-separated value of users to attach to the collection.
name: Option<String>Collection name.
public: Option<u8>0 for private, 1 for public (legacy).
type: Option<u8>0 = standard, 3 = Featured collection, 4 = public. If 3 or 4 then public should be set to 1.
parent: Option<u32>ID of parent featured collection. Set to 0 to create a new root level collection (see below). Applies to Featured collections only.
force_featured_collection_type: Option<u8>Required to be set to 1 if creating a root level featured collection (parent=0). Applies to Featured collections only.
thumbnail_selection_method: Option<u32>0 = no image, 1 = most popular image, 10 - most popular images, 100 - manually select image. Applies to Featured collections only.
bg_img_resource_ref: Option<u32>Resource ID to use as thumbnail. Only if thumbnail_selection_method =100. Applies to Featured collections only.