pub struct GetNodesRequest {
pub ref: u32,
pub parent: Option<u32>,
pub recursive: Option<bool>,
pub offset: Option<u32>,
pub rows: Option<u32>,
pub name: Option<String>,
pub use_count: Option<bool>,
pub order_by_translated_name: Option<bool>,
}Fields
ref: u32The ID of the metadata field to retrieve nodes from.
parent: Option<u32>Restrict results to children of this parent node ID.
recursive: Option<bool>If set, retrieves all descendant nodes recursively.
offset: Option<u32>Number of nodes to skip, used for pagination.
rows: Option<u32>Maximum number of nodes to return.
name: Option<String>Filter nodes by name (partial match).
use_count: Option<bool>If set, includes the number of resources using each node.
order_by_translated_name: Option<bool>If set, orders results by the translated node name.
Implementations
Sourceimpl GetNodesRequest
impl GetNodesRequest
pub fn new(ref: u32) -> Self
pub fn parent(self, parent: u32) -> Self
pub fn recursive(self, recursive: bool) -> Self
pub fn offset(self, offset: u32) -> Self
pub fn rows(self, rows: u32) -> Self
pub fn name(self, name: impl Into<String>) -> Self
pub fn use_count(self, use_count: bool) -> Self
pub fn order_by_translated_name(self, order_by_translated_name: bool) -> Self