MetadataApi

Struct MetadataApi 

pub struct MetadataApi<'a> { /* private fields */ }

Implementations

Source

impl<'a> MetadataApi<'a>

Sub-API for metadata endpoints.

pub async fn get_field_options( &self, request: GetFieldOptionsRequest, ) -> Result<Value, RsError>

For a given field, return all the available tags (nodes) or selectable options.

Arguments
TODO: Returns
TODO: Errors
TODO: Examples
pub async fn get_node_id( &self, request: GetNodeIdRequest, ) -> Result<Value, RsError>

Find a node ID (entry in a fixed tag field) given the name of the node.

Arguments
TODO: Returns
TODO: Errors
TODO: Examples
pub async fn get_nodes( &self, request: GetNodesRequest, ) -> Result<Value, RsError>

Get all nodes (fixed keywords) from database for a specific metadata field or parent.

Arguments
TODO: Returns
TODO: Errors
TODO: Examples
pub async fn add_resource_nodes( &self, request: AddResourceNodesRequest, ) -> Result<Value, RsError>

Add all node IDs (field options) in the list to a resource.

Arguments
TODO: Returns
TODO: Errors
TODO: Examples
pub async fn add_resource_nodes_multi( &self, request: AddResourceNodesMultiRequest, ) -> Result<Value, RsError>

Add all node IDs (field options) in the list to the resources specified.

Arguments
TODO: Returns
TODO: Errors
TODO: Examples
pub async fn set_node(&self, request: SetNodeRequest) -> Result<Value, RsError>

Create a new node (option for a fixed list field).

Arguments
TODO: Returns
TODO: Errors
TODO: Examples
pub async fn get_resource_type_fields( &self, request: GetResourceTypeFieldsRequest, ) -> Result<Value, RsError>

Get metadata field information for all (matching) fields.

Available from RS version 10.3+ and requires permission a.

Arguments
TODO: Returns
TODO: Errors
TODO: Examples
pub async fn create_resource_type_field( &self, request: CreateResourceTypeFieldRequest, ) -> Result<Value, RsError>

Create a metadata field.

Available from RS version 10.3+ and requires permission a.

Arguments
TODO: Returns
TODO: Errors
TODO: Examples
pub async fn toggle_active_state_for_nodes( &self, request: ToggleActiveStatesForNodesRequest, ) -> Result<Value, RsError>

Toggle nodes’ active state.

Available from RS version 10.4+ and requires permission k.

Arguments
TODO: Returns
TODO: Errors
TODO: Examples
pub async fn update_field( &self, request: UpdateFieldRequest, ) -> Result<Value, RsError>

Set the value of a metadata field.

Arguments
TODO: Returns
TODO: Errors
TODO: Examples