pub struct SetNodeRequest {
pub ref: u32,
pub resource_type_field: u32,
pub name: String,
pub parent: Option<String>,
pub order_by: Option<u32>,
pub returnexisting: Option<bool>,
}Fields
ref: u32The ID of an existing node to update, or 0 to create a new one.
resource_type_field: u32The ID of the resource type field this node belongs to.
name: StringThe name of the node.
parent: Option<String>The ID of the parent node, if this is a child node.
order_by: Option<u32>Position used to order this node relative to siblings.
returnexisting: Option<bool>If set, returns the existing node instead of creating a duplicate.
Implementations