pub struct AddAlternativeFileRequest {
pub resource: u32,
pub name: String,
pub description: Option<String>,
pub file_name: Option<String>,
pub file_extension: Option<String>,
pub file_size: Option<u64>,
pub alt_type: Option<String>,
pub file: Option<String>,
}Fields
resource: u32The ID of the resource to attach the alternative file to.
name: StringDisplay name for the alternative file.
description: Option<String>Optional description of the alternative file.
file_name: Option<String>Original file name of the alternative file.
file_extension: Option<String>File extension of the alternative file (e.g. "pdf").
file_size: Option<u64>Size of the file in bytes.
alt_type: Option<String>Alternative file type identifier used to categorise the file.
file: Option<String>Local server path or publicly accessible URL of the file to attach.
Implementations
Sourceimpl AddAlternativeFileRequest
impl AddAlternativeFileRequest
pub fn new(resource: u32, name: impl Into<String>) -> Self
pub fn description(self, description: impl Into<String>) -> Self
pub fn file_name(self, file_name: impl Into<String>) -> Self
pub fn file_extension(self, file_extension: impl Into<String>) -> Self
pub fn file_size(self, file_size: u64) -> Self
pub fn alt_type(self, alt_type: impl Into<String>) -> Self
pub fn file(self, file: impl Into<String>) -> Self