pub struct GetAlternativeFilesRequest {
pub resource: u32,
pub orderby: Option<String>,
pub sort: Option<SortOrder>,
pub type: Option<String>,
}Fields
resource: u32The ID of the resource whose alternative files should be returned.
orderby: Option<String>Field name to order the alternative files by.
sort: Option<SortOrder>Sort direction for the results.
type: Option<String>Filter results to only alternative files of this type.
Implementations