pub struct ResourceLogLastRowsRequest {
pub minref: Option<u32>,
pub days: Option<u32>,
pub maxrecords: Option<u32>,
pub field: Option<List<u32>>,
pub log_code: Option<List<String>>,
}Fields
minref: Option<u32>Only return log entries with a ref greater than this value.
days: Option<u32>Only return log entries from the last N days.
maxrecords: Option<u32>Maximum number of log entries to return.
field: Option<List<u32>>Comma-separated list of field IDs to limit results to.
log_code: Option<List<String>>Comma-separated list of log codes to limit results to (e.g. "FD" for field data changes).
Implementations