SearchApi

Struct SearchApi 

pub struct SearchApi<'a> { /* private fields */ }
Sub-API for search endpoints.

Implementations

Source

impl<'a> SearchApi<'a>

Performs a search and returns matching resources.

Arguments
TODO: Errors

Returns RsError::OperationFailed if the search returns no results or the user lacks search permissions.

Examples
let results = client.search()
    .do_search(DoSearchRequest::new("cat").sort(SortOrder::Desc))
    .await?;

let specific_results = client.search()
    .do_search(
        DoSearchRequest::new("cat")
            .fetchrows("100")
            .offset(50)
            .archive(0)
    )
    .await?;
Examples found in repository?
examples/basic.rs (line 27)
8async fn main() {
9    dotenvy::from_path("examples/.env").ok();
10
11    let base_url = std::env::var("RS_BASE_URL").expect("RS_BASE_URL not set");
12    let user = std::env::var("RS_USER").expect("RS_USER not set");
13    let _password = std::env::var("RS_PASS").expect("RS_PASS not set");
14    let key = std::env::var("RS_KEY").expect("RS_KEY not set");
15
16    let client = Client::builder()
17        .base_url(&base_url)
18        .expect("Error when setting base_url")
19        .user_key(&user, &key)
20        // .session_key(&user, &password)
21        .build()
22        .await
23        .expect("Error when building client");
24
25    let search_result = client
26        .search()
27        .do_search(DoSearchRequest::new("909").sort(SortOrder::Asc))
28        .await;
29
30    match search_result {
31        Ok(response) => println!("{:#?}", response),
32        Err(e) => println!("Error: {}", e),
33    }
34
35    let system_result = client
36        .system()
37        .get_daily_stat_summary(GetDailyStatSummaryRequest::new().days(31))
38        .await;
39
40    match system_result {
41        Ok(response) => println!("{:#?}", response),
42        Err(e) => println!("Error: {}", e),
43    }
44
45    let message_result = client
46        .message()
47        .get_user_message(GetUserMessageRequest::new(12))
48        .await;
49
50    match message_result {
51        Ok(response) => println!("{:#?}", response),
52        Err(e) => println!("Error: {}", e),
53    }
54}
pub async fn search_get_previews( &self, request: SearchGetPreviewsRequest, ) -> Result<Value, RsError>

Performs a search and returns matching resources including URLs for requested preview sizes.

Arguments
TODO: Errors

Returns RsError::OperationFailed if the search returns no results or the user lacks search permissions.

Examples
let results = client.search()
    .search_get_previews(SearchGetPreviewsRequest::new("cat").getsizes("thm,scr"))
    .await?;

let specific_results = client.search()
    .search_get_previews(
        SearchGetPreviewsRequest::new("cat")
            .getsizes("thm,scr,pre")
            .previewext("jpg")
            .sort(SortOrder::Desc)
            .fetchrows("0,50")
    )
    .await?;