Module client

Module client 

Structs

Client
some endpoints return JSON with status codes, some plain text, some error with 200 status code, etc. for now just try to parse and hope for the best. Montala stated they are working on an OpenAPI spec for the api which should allow for much better handling in the future. So, for now, responses can be:
ClientBuilder